/*$Id: d_coment.h,v 17.4 2000/03/19 04:20:02 al Exp $ -*- C++ -*-
 $ comment statement
 */
#ifndef D_COMENT_H
#define D_COMENT_H
#include "e_card.h"
/*--------------------------------------------------------------------------*/
class DEV_COMMENT : public CARD {
private:
  std::string	_s;
  explicit	DEV_COMMENT(const DEV_COMMENT& p)
				:CARD(p) {untested(); set_constant(true);}
public:
  explicit	DEV_COMMENT()	:CARD()  {set_constant(true);}
private: // override virtual
  char		id_letter()const{return '\0';}
  const char*	dev_type()const	{untested(); return "comment";}
  CARD*		clone()const	{untested(); return new DEV_COMMENT(*this);}
  void		parse(CS& cmd);
  void		print(OMSTREAM& where, int detail)const;
};
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
#endif
